==> inca_tool-1.0.0-py3-none-any.whl: inca/woodprovision/preprocessing/N2K.py <==
# -*- coding: utf-8 -*-
# Copyright (c) 2022 European Union.
#
# The tool was developed with the contribution of the Joint Research Centre of the European Commission.
#
# This program is free software: you can redistribute it and/or modify it under the terms of the European Union Public
# Licence, either version 1.2 of the License, or (at your option) any later version.
# You may not use this work except in compliance with the Licence.
#
# You may obtain a copy of the Licence at: https://joinup.ec.europa.eu/collection/eupl/eupl-guidelines-faq-infographics
#
# Unless required by applicable law or agreed to in writing, software distributed under the Licence is distributed on
# an "AS IS" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#
# See the Licence for the specific language governing permissions and limitations under the Licence.

import argparse
import logging
import os
import time
import subprocess
import sys

import pandas as pd
import numpy as np
import geopandas as gpd

import inca
import inca.woodprovision.preprocessing

logger = logging.getLogger(__name__)

description = 'Natura 2000 raster preprocessing for wood provision'


def main():
    start_time = time.time()

    options = parse_args()

    inca.set_up_console_logging(options.verbose)

    logger.info('START OF MODULE: %s', description)

    n2k_preprocessing(options)

    logger.info('All processing successfully done. Have a nice day.')
    logger.debug('TOTAL TIME IN MINUTES: %10.4f', (time.time() - start_time) / 60)
    logger.debug('END OF MODULE: %s', description)


def parse_args():
    parser = argparse.ArgumentParser('Create raster files of Natura 2000 areas.')
    parser.add_argument('path_in', help='Path to input natura 2000 shapefile.', metavar='Natura_2000_shp')
    parser.add_argument('year', type=int, help='Year of the natura 2000 map.')
    parser.add_argument('path_csv', help='Path to N2K data information file.', metavar='Natura_2000_csv')
    parser.add_argument('path_out_base', help='Path to output folder.', metavar='output_dir')
    parser.add_argument('--nodata', help='New nodata value.', dest='new_nodata')
    parser.add_argument('-v', '--verbose', action='store_true', help='verbose output')

    return parser.parse_args()


def n2k_preprocessing(options):
    os.makedirs(options.path_out_base, exist_ok=True)
    path_out = os.path.join(os.path.normpath(options.path_out_base), 'N2K_{}.tif'.format(options.year))
    try:
        gdf = gpd.read_file(options.path_in)
        gdf = gdf[['SITECODE', 'geometry']]
        # convert csv to something more useful
        csv = pd.read_csv(options.path_csv, usecols=['SITECODE', 'SITETYPE', 'DATE_SPA', 'DATE_SAC', 'DATE_PROP_SCI'])
        csv.DATE_PROP_SCI = csv.DATE_PROP_SCI.fillna(csv.DATE_SAC)
        csv['date'] = np.nan
        csv.loc[csv['SITETYPE'] == 'A', 'date'] = csv.loc[csv['SITETYPE'] == 'A', 'DATE_SPA']
        csv.loc[csv['SITETYPE'].isin(['B', 'C']), 'date'] = csv.loc[csv['SITETYPE'].isin(['B', 'C']), 'DATE_PROP_SCI']
        csv = csv.filter(items=['SITECODE', 'date'])
        output = csv[csv['date'] < (((int(options.year)+1)*10000 + 101)*10**6)]

        # Filter and write out data.
        gdf_total = gdf.merge(output, how='inner', on='SITECODE')
        rasterize(gdf_total, path_out, nodata_value=0, dtype='Byte')
        logger.debug('done.')
    except Exception as e:
        # delete file to rerun after error
        if os.path.exists(path_out):
            os.remove(path_out)
        logger.error('Failed to generate Natura 2000 map for year %s: "%s."', options.year, e)
        sys.exit(1)


def rasterize(gdb, path_out, nodata_value=0, dtype='Float32'):
    """Rasterize a given geopandas dataframe."""
    temp_out = os.path.join(os.path.dirname(path_out), 'vector_{}.shp'.format(os.path.basename(path_out).split('.')[0]))

    cmd = 'gdal_rasterize -l {} -burn 1.0 -init {} -a_nodata {} -co COMPRESS=LZW '\
        '-ot {} -te {} {} {} {} -tr {} {} {} {}'.format(
            os.path.basename(temp_out).split('.shp')[0],
            nodata_value,
            nodata_value,
            dtype,
            "2549000.0",
            "1402000.0",
            "6558000.0",
            "5447000.0",
            1000.0,
            1000.0,
            temp_out,
            path_out)

    if not os.path.exists(path_out):
        try:
            gdb.to_file(temp_out)
            subprocess.check_call(cmd, shell=True)
        except Exception:
            raise OSError('Could not rasterize needed vector file')
    else:
        print('Output file already exists. Remove first.')
        pass


if __name__ == '__main__':
    # hack to get the proper logger when running the script directly with 'python preprocessing_N2K.py'
    logger = logging.getLogger(inca.woodprovision.preprocessing.__name__)
    main()

==> inca_tool-2.1.1-py3-none-any.whl: inca/woodprovision/preprocessing/N2K.py <==
# -*- coding: utf-8 -*-
# Copyright (c) 2022 European Union.
#
# The tool was developed with the contribution of the Joint Research Centre of the European Commission.
#
# This program is free software: you can redistribute it and/or modify it under the terms of the European Union Public
# Licence, either version 1.2 of the License, or (at your option) any later version.
# You may not use this work except in compliance with the Licence.
#
# You may obtain a copy of the Licence at: https://joinup.ec.europa.eu/collection/eupl/eupl-guidelines-faq-infographics
#
# Unless required by applicable law or agreed to in writing, software distributed under the Licence is distributed on
# an "AS IS" basis, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#
# See the Licence for the specific language governing permissions and limitations under the Licence.

import argparse
import logging
import os
import time
import subprocess
import sys

import pandas as pd
import numpy as np
import geopandas as gpd

import inca
import inca.woodprovision.preprocessing

logger = logging.getLogger(__name__)

description = 'Natura 2000 raster preprocessing for wood provision'


def main():
    start_time = time.time()

    options = parse_args()

    inca.set_up_console_logging(options.verbose)

    logger.info('START OF MODULE: %s', description)

    n2k_preprocessing(options)

    logger.info('All processing successfully done. Have a nice day.')
    logger.debug('TOTAL TIME IN MINUTES: %10.4f', (time.time() - start_time) / 60)
    logger.debug('END OF MODULE: %s', description)


def parse_args():
    parser = argparse.ArgumentParser('Create raster files of Natura 2000 areas.')
    parser.add_argument('path_in', help='Path to input natura 2000 shapefile.', metavar='Natura_2000_shp')
    parser.add_argument('year', type=int, help='Year of the natura 2000 map.')
    parser.add_argument('path_csv', help='Path to N2K data information file.', metavar='Natura_2000_csv')
    parser.add_argument('path_out_base', help='Path to output folder.', metavar='output_dir')
    parser.add_argument('--nodata', help='New nodata value.', dest='new_nodata')
    parser.add_argument('-v', '--verbose', action='store_true', help='verbose output')

    return parser.parse_args()


def n2k_preprocessing(options):
    os.makedirs(options.path_out_base, exist_ok=True)
    path_out = os.path.join(os.path.normpath(options.path_out_base), 'N2K_{}.tif'.format(options.year))
    try:
        gdf = gpd.read_file(options.path_in)
        gdf = gdf[['SITECODE', 'geometry']]
        # convert csv to something more useful
        csv = pd.read_csv(options.path_csv, usecols=['SITECODE', 'SITETYPE', 'DATE_SPA', 'DATE_SAC', 'DATE_PROP_SCI'])
        csv.DATE_PROP_SCI = csv.DATE_PROP_SCI.fillna(csv.DATE_SAC)
        csv['date'] = np.nan
        csv.loc[csv['SITETYPE'] == 'A', 'date'] = csv.loc[csv['SITETYPE'] == 'A', 'DATE_SPA']
        csv.loc[csv['SITETYPE'].isin(['B', 'C']), 'date'] = csv.loc[csv['SITETYPE'].isin(['B', 'C']), 'DATE_PROP_SCI']
        csv = csv.filter(items=['SITECODE', 'date'])
        csv['date'] = pd.to_datetime(csv['date']).dt.year
        output = csv[csv['date'] < (options.year+1)]
        # Filter and write out data.
        gdf_total = gdf.merge(output, how='inner', on='SITECODE')
        rasterize(gdf_total, path_out, nodata_value=0, dtype='Byte')
        logger.debug('done.')
    except Exception as e:
        # delete file to rerun after error
        if os.path.exists(path_out):
            os.remove(path_out)
        logger.error('Failed to generate Natura 2000 map for year %s: "%s."', options.year, e)
        sys.exit(1)


def rasterize(gdb, path_out, nodata_value=0, dtype='Float32'):
    """Rasterize a given geopandas dataframe."""
    temp_out = os.path.join(os.path.dirname(path_out), 'vector_{}.shp'.format(os.path.basename(path_out).split('.')[0]))

    cmd = 'gdal_rasterize -l {} -burn 1.0 -init {} -a_nodata {} -co COMPRESS=LZW '\
        '-ot {} -te {} {} {} {} -tr {} {} {} {}'.format(
            os.path.basename(temp_out).split('.shp')[0],
            nodata_value,
            nodata_value,
            dtype,
            "900000.0",
            "900000.0",
            "7400000.0",
            "5500000.0",
            100.0,
            100.0,
            temp_out,
            path_out)

    if not os.path.exists(path_out):
        try:
            gdb.to_file(temp_out)
            subprocess.check_call(cmd, shell=True)
        except Exception:
            raise OSError('Could not rasterize needed vector file')
    else:
        print('Output file already exists. Remove first.')
        pass


if __name__ == '__main__':
    # hack to get the proper logger when running the script directly with 'python preprocessing_N2K.py'
    logger = logging.getLogger(inca.woodprovision.preprocessing.__name__)
    main()
